# README #

### What is this repository for? ###

This repository contains tools to download, calibrate, and generate change statistics from JAXA's [ALOS mosaic](http://www.eorc.jaxa.jp/ALOS/en/palsar_fnf/fnf_index.htm) product for forest monitoring purposes.

This repository includes tools for the following tasks:

* Downloading ALOS-1 and ALOS-2 data from JAXA.
* Pre-processing (speckle filtering, up/downsampling, reprojection) and calibration (gamma0, AGB) of the ALOS mosaic product for biomass mapping.
* Methods for change detection, including identification of growth, deforestation and degradation.

### How do I get set up? ###

These tools are written in Python for use in Linux. All libraries used are available within Anaconda Python.

### How does it work? ###

Full documentation is hosted at: http://biota.readthedocs.io/ (under construction).

### Who do I talk to? ###

Written and maintained by Samuel Bowers (sam.bowers@ed.ac.uk).
